@@ -16,8 +16,8 @@ test_that("crs parameter working", {
   
   a <- load_geouy("Secciones", crs = 4326)
   a1 <- sf::st_crs(a)
-  testthat::expect_equal(a1[1], structure(list(epsg = 4326L), .Names = "epsg"))
+  testthat::expect_equal(a1[1], list(input = "EPSG:4326"))
   a <- load_geouy("Secciones", crs = 32721)
   a1 <- sf::st_crs(a)
-  testthat::expect_equal(a1[1], structure(list(epsg = 32721L), .Names = "epsg"))
-})
\ No newline at end of file
+  testthat::expect_equal(a1[1], list(input = "EPSG:32721"))
+  })
\ No newline at end of file
